Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2370)

Unified Diff: device/bluetooth/bluetooth_remote_gatt_descriptor_bluez.cc

Issue 1542163002: Switch to standard integer types in device/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: win Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: device/bluetooth/bluetooth_remote_gatt_descriptor_bluez.cc
diff --git a/device/bluetooth/bluetooth_remote_gatt_descriptor_bluez.cc b/device/bluetooth/bluetooth_remote_gatt_descriptor_bluez.cc
index 4bf9ab053ef53eb3f063e3d12f529268ab8f1426..c74b1a079e56902507243a2a3bbbb4715ae35766 100644
--- a/device/bluetooth/bluetooth_remote_gatt_descriptor_bluez.cc
+++ b/device/bluetooth/bluetooth_remote_gatt_descriptor_bluez.cc
@@ -16,10 +16,10 @@ namespace bluez {
namespace {
-// Stream operator for logging vector<uint8>.
-std::ostream& operator<<(std::ostream& out, const std::vector<uint8> bytes) {
+// Stream operator for logging vector<uint8_t>.
+std::ostream& operator<<(std::ostream& out, const std::vector<uint8_t> bytes) {
out << "[";
- for (std::vector<uint8>::const_iterator iter = bytes.begin();
+ for (std::vector<uint8_t>::const_iterator iter = bytes.begin();
iter != bytes.end(); ++iter) {
out << base::StringPrintf("%02X", *iter);
}
@@ -57,7 +57,8 @@ bool BluetoothRemoteGattDescriptorBlueZ::IsLocal() const {
return false;
}
-const std::vector<uint8>& BluetoothRemoteGattDescriptorBlueZ::GetValue() const {
+const std::vector<uint8_t>& BluetoothRemoteGattDescriptorBlueZ::GetValue()
+ const {
bluez::BluetoothGattDescriptorClient::Properties* properties =
bluez::BluezDBusManager::Get()
->GetBluetoothGattDescriptorClient()
@@ -94,7 +95,7 @@ void BluetoothRemoteGattDescriptorBlueZ::ReadRemoteDescriptor(
}
void BluetoothRemoteGattDescriptorBlueZ::WriteRemoteDescriptor(
- const std::vector<uint8>& new_value,
+ const std::vector<uint8_t>& new_value,
const base::Closure& callback,
const ErrorCallback& error_callback) {
VLOG(1) << "Sending GATT characteristic descriptor write request to "
« no previous file with comments | « device/bluetooth/bluetooth_remote_gatt_descriptor_bluez.h ('k') | device/bluetooth/bluetooth_remote_gatt_service_android.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698